==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-kogito-runtimes/addons/common/persistence/mongodb/src/main/java/org/kie/kogito/mongodb/AbstractProcessInstancesFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.kogito.mongodb;

import org.kie.kogito.mongodb.transaction.AbstractTransactionManager;
import org.kie.kogito.process.Process;
import org.kie.kogito.process.ProcessInstancesFactory;

import com.mongodb.client.MongoClient;

public abstract class AbstractProcessInstancesFactory implements ProcessInstancesFactory {

    private final MongoClient mongoClient;
    private final String dbName;
    private final Boolean lock;
    private final AbstractTransactionManager transactionManager;

    public AbstractProcessInstancesFactory(MongoClient mongoClient, String dbName, Boolean lock, AbstractTransactionManager transactionManager) {
        this.mongoClient = mongoClient;
        this.dbName = dbName;
        this.lock = lock;
        this.transactionManager = transactionManager;
    }

    @Override
    public MongoDBProcessInstances<?> createProcessInstances(Process<?> process) {
        return new MongoDBProcessInstances<>(mongoClient, process, dbName, transactionManager, lock);
    }

}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-kogito-runtimes/addons/common/persistence/mongodb/src/main/java/org/kie/kogito/mongodb/AbstractProcessInstancesFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.kogito.mongodb;

import org.kie.kogito.internal.process.runtime.HeadersPersistentConfig;
import org.kie.kogito.mongodb.transaction.AbstractTransactionManager;
import org.kie.kogito.process.Process;
import org.kie.kogito.process.ProcessInstancesFactory;

import com.mongodb.client.MongoClient;

public abstract class AbstractProcessInstancesFactory implements ProcessInstancesFactory {

    private final MongoClient mongoClient;
    private final String dbName;
    private final Boolean lock;
    private final AbstractTransactionManager transactionManager;
    private HeadersPersistentConfig headersConfig;

    public AbstractProcessInstancesFactory(MongoClient mongoClient, String dbName, Boolean lock, AbstractTransactionManager transactionManager) {
        this(mongoClient, dbName, lock, transactionManager, null);
    }

    public AbstractProcessInstancesFactory(MongoClient mongoClient, String dbName, Boolean lock,
            AbstractTransactionManager transactionManager, HeadersPersistentConfig headersPersistentConfig) {
        this.mongoClient = mongoClient;
        this.dbName = dbName;
        this.lock = lock;
        this.transactionManager = transactionManager;
        this.headersConfig = headersPersistentConfig;
    }

    @Override
    public MongoDBProcessInstances<?> createProcessInstances(Process<?> process) {
        return new MongoDBProcessInstances<>(mongoClient, process, dbName, transactionManager, lock, headersConfig);
    }

}
